@@ -326,8 +326,8 @@ def make(n, q, k, args):
                                u'/root/deploy'      : deploy_files[node],
                                u'/root/user.yaml'   : user_config_yaml,
                                u'/root/config.yaml' : initial_config_yaml,
-                               u'/root/global.yaml' : global_config_yaml},
-                               u'/root/fact_exports': fact_exports},
+                               u'/root/global.yaml' : global_config_yaml,
+                               u'/root/fact_exports': fact_exports },
                         meta={'ci_test_id' : test_id}
                         )
 
